==> casacore_2.1.0.orig.tar.gz: casacore-2.1.0/casa/System/AipsrcValue2.cc <==
//# AipsrcValue2.cc: Class to read values from the Aipsrc general resource files 
//# Copyright (C) 1995,1996,1997,1998,1999,2001,2002,2003
//# Associated Universities, Inc. Washington DC, USA.
//#
//# This library is free software; you can redistribute it and/or modify it
//# under the terms of the GNU Library General Public License as published by
//# the Free Software Foundation; either version 2 of the License, or (at your
//# option) any later version.
//#
//# This library is distributed in the hope that it will be useful, but WITHOUT
//# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
//# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
//# License for more details.
//#
//# You should have received a copy of the GNU Library General Public License
//# along with this library; if not, write to the Free Software Foundation,
//# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
//#
//# Correspondence concerning AIPS++ should be addressed as follows:
//#        Internet email: aips2-request@nrao.edu.
//#        Postal address: AIPS++ Project Office
//#                        National Radio Astronomy Observatory
//#                        520 Edgemont Road
//#                        Charlottesville, VA 22903-2475 USA
//#
//# $Id$

//# Includes

#include <casacore/casa/System/AipsrcValue.h>
#include <casacore/casa/Utilities/Assert.h>
#include <casacore/casa/Quanta/Quantum.h>
#include <casacore/casa/sstream.h>

namespace casacore { //# NAMESPACE CASACORE - BEGIN

template <> 
Bool AipsrcValue<String>::find(String &value,
			       const String &keyword,
			       const Unit &, const Unit &) {
  String res;
  Bool x = Aipsrc::find(res, keyword, 0);
  value = res;
  return x;
}

} //# NAMESPACE CASACORE - END

==> casacore_2.2.0.orig.tar.gz: casacore-2.2.0/casa/System/AipsrcValue2.cc <==
//# AipsrcValue2.cc: Class to read values from the Aipsrc general resource files 
//# Copyright (C) 1995,1996,1997,1998,1999,2001,2002,2003
//# Associated Universities, Inc. Washington DC, USA.
//#
//# This library is free software; you can redistribute it and/or modify it
//# under the terms of the GNU Library General Public License as published by
//# the Free Software Foundation; either version 2 of the License, or (at your
//# option) any later version.
//#
//# This library is distributed in the hope that it will be useful, but WITHOUT
//# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
//# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
//# License for more details.
//#
//# You should have received a copy of the GNU Library General Public License
//# along with this library; if not, write to the Free Software Foundation,
//# Inc., 675 Massachusetts Ave, Cambridge, MA 02139, USA.
//#
//# Correspondence concerning AIPS++ should be addressed as follows:
//#        Internet email: aips2-request@nrao.edu.
//#        Postal address: AIPS++ Project Office
//#                        National Radio Astronomy Observatory
//#                        520 Edgemont Road
//#                        Charlottesville, VA 22903-2475 USA
//#
//# $Id$

//# Includes

#include <casacore/casa/System/AipsrcValue.h>
#include <casacore/casa/Utilities/Assert.h>
#include <casacore/casa/Quanta/Quantum.h>
#include <casacore/casa/sstream.h>

namespace casacore { //# NAMESPACE CASACORE - BEGIN

//# Instantiate extern templates for often used types.
#ifdef AIPS_CXX11
    template class AipsrcValue<Bool>;
    template class AipsrcValue<Int>;
    template class AipsrcValue<Double>;
    template class AipsrcValue<String>;
#endif

template <> 
Bool AipsrcValue<String>::find(String &value,
			       const String &keyword,
			       const Unit &, const Unit &) {
  String res;
  Bool x = Aipsrc::find(res, keyword, 0);
  value = res;
  return x;
}

} //# NAMESPACE CASACORE - END
